@@ -1,13 +1,13 @@
 from __future__ import annotations
 from reamber.base.HitObject import HitObject
-from reamber.osu.OsuHitObjectMeta import OsuHitObjectMeta
+from reamber.osu.OsuNoteObjectMeta import OsuNoteObjectMeta
 from dataclasses import dataclass
 
 
 @dataclass
-class OsuHitObject(HitObject, OsuHitObjectMeta):
+class OsuHitObject(HitObject, OsuNoteObjectMeta):
     @staticmethod
-    def readString(s: str, keys: int) -> OsuHitObject:
+    def readString(s: str, keys: int) -> OsuHitObject or None:
         if s.isspace(): return None
 
         sComma = s.split(",")
@@ -29,6 +29,6 @@ class OsuHitObject(HitObject, OsuHitObjectMeta):
         return this
 
     def writeString(self, keys: int) -> str:
-        return f"{OsuHitObjectMeta.columnToXAxis(self.column, keys=keys)},{192}," \
+        return f"{OsuNoteObjectMeta.columnToXAxis(self.column, keys=keys)},{192}," \
                f"{int(self.offset)},{1},{self.hitsoundSet},{self.sampleSet}:" \
                f"{self.additionSet}:{self.customSet}:{self.volume}:{self.hitsoundFile}"
